@@ -961,6 +961,7 @@ class account():
 
     def parse_time(self, timestr):
         #parses a time string from twitter into a date object
+        #timestr = "Wed Apr 07 09:45:28 +0000 2010"
         if (timestr.find("+") == -1):
             #negative offset from UTC
             strippedDate = timestr[0: timestr.find("-")] + "+0000" + timestr[timestr.find("-") + 5: len(timestr)]
@@ -978,50 +979,42 @@ class account():
 
             msgDate = datetime.datetime.strptime(strippedDate, "%a %b %d %H:%M:%S +0000 %Y")
             #msgDate = date.fromtimestamp(secsSinceEpoc)
-
-            timestamp = msgDate.time()
-            print timestamp.tzinfo
-            #print datetime.datetime.tzname()
-            #msgDate = msgDate.astimezone(LocalTimezone())
-            t = time.time()
-
-            # we want something like '2007-10-18 14:00+0100'
-            if time.localtime(t).tm_isdst and time.daylight:
-                tz = time.altzone
-            else:
-                tz = time.timezone
-            if (minus):
-                td = datetime.timedelta(hours=0 - hoursOffset, seconds=tz)
-            else:
-                td = datetime.timedelta(hours=hoursOffset, seconds=tz)
-            print td
-            timestamp = msgDate - td
-            mytz = "%+4.4d" % (tz / -(60 * 60) * 100) # time.timezone counts westwards!
-            print timestamp
-
-            dt = msgDate
-            nowstring = timestamp.strftime('%a, %b %d %Y %H:%M:%S')  # %Z (timezone) would be empty
-            #nowstring = "%s%s" % (dts, mytz)
-
-            print nowstring
-            return nowstring
-
-
         except ValueError:
-            msgDate = datetime.datetime.strptime(timestr, "%a, %d %b %Y %H:%M:%S +0000")
-            #msgDate = date.fromtimestamp(secsSinceEpoc)
-            # we want something like '2007-10-18 14:00+0100'
-            t = time.time()
-            if time.localtime(t).tm_isdst and time.daylight:
-                tz = time.altzone
-            else:
-                tz = time.timezone
+            try:
+                msgDate = datetime.datetime.strptime(timestr, "%a, %d %b %Y %H:%M:%S +0000")
+            except ValueError:
+                try:
+                    msgDate = datetime.datetime.strptime(timestr, "%a %b %d %H:%M:%S +0000 %Y")
+                except ValueError, e:
+                    print e
+                    return timestr
+
+        timestamp = msgDate.time()
+        print timestamp.tzinfo
+        #print datetime.datetime.tzname()
+        #msgDate = msgDate.astimezone(LocalTimezone())
+        t = time.time()
+
+        # we want something like '2007-10-18 14:00+0100'
+        if time.localtime(t).tm_isdst and time.daylight:
+            tz = time.altzone
+        else:
+            tz = time.timezone
+        if (minus):
+            td = datetime.timedelta(hours=0 - hoursOffset, seconds=tz)
+        else:
+            td = datetime.timedelta(hours=hoursOffset, seconds=tz)
+        print td
+        timestamp = msgDate - td
+        mytz = "%+4.4d" % (tz / -(60 * 60) * 100) # time.timezone counts westwards!
+        print timestamp
+
+        dt = msgDate
+        nowstring = timestamp.strftime('%a, %b %d %Y %H:%M:%S')  # %Z (timezone) would be empty
+        #nowstring = "%s%s" % (dts, mytz)
+
+        print nowstring
+        return nowstring
+
 
-            td = datetime.timedelta(seconds=tz)
-            timestamp = msgDate - td
-            nowstring = timestamp.strftime('%a, %b %d %Y %H:%M:%S')
-            today = datetime.date.today()
 
-            #print datetime.datetime.tzname()
-            #msgDate = msgDate.astimezone(datetime.tzinfo("GMT +1"))
-            return nowstring
