@@ -289,7 +289,7 @@ class Witter():
 
         retweet = ' '.join(words)
 
-        self.ui.setTweetText("RT: " + retweet)
+        self.ui.setTweetText("RT " + retweet)
         self.ui.setCursorAt(0)
 
 
@@ -843,10 +843,6 @@ class Witter():
                             print "bitly gave error response"
                         except KeyError:
                             print "bitly gave key error response"
-                        except BadStatusLine, e2:
-                            print e2
-                            note = osso.SystemNote(self.osso_c)
-                            note.system_note_dialog("Bad status response")
         return data
 
 
